@@ -1,7 +1,7 @@
 /*
   fonts.c
 
-  Copyright (c) 2009-2017
+  Copyright (c) 2009-2020
   http://www.tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
@@ -56,6 +56,7 @@
 	The renaming ends here.
 */
 
+#include "platform.h"
 #include "fonts.h"
 #include "i18n.h"
 #include "progressbar.h"
@@ -67,8 +68,10 @@
 #include "win32_print.h"
 #endif
 
-#ifdef __APPLE__
+#if defined(__MACOS__)
 #include "macos.h"
+#elif defined(__IOS__)
+#include "ios.h"
 #endif
 
 #ifdef __HAIKU__
@@ -193,7 +196,7 @@ TuxPaint_Font *load_locale_font(TuxPaint_Font * fallback, int size)
 
       if (!ret)
         {
-          snprintf(str, sizeof(str), "%s/%s.ttf", macos_fontsPath(), lang_prefix);
+          snprintf(str, sizeof(str), "%s/%s.ttf", apple_fontsPath(), lang_prefix);
           ret = TuxPaint_Font_OpenFont("", str, size);
         }
 #endif
@@ -901,7 +904,7 @@ static void groupfonts(void)
   //printf("groupfonts() qsort(user_font_families 2...)\n");
   //fflush(stdout);
   if (num_font_families > 0 && user_font_families[0]->score < 0)
-    printf("sorted the wrong way, or all fonts were unusable\n");
+    fprintf(stderr, "sorted the wrong way, or all fonts were unusable\n");
 #if 0
 // THREADED_FONTS
   printf("Trim starting with %d families\n", num_font_families);
@@ -970,14 +973,16 @@ static void loadfonts(SDL_Surface * screen, const char *const dir)
 
       result = find_directory(B_SYSTEM_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
       loadfonts(screen, buffer);
-      result = find_directory(B_COMMON_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
+      result = find_directory(B_SYSTEM_NONPACKAGED_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
       loadfonts(screen, buffer);
       result = find_directory(B_USER_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
       loadfonts(screen, buffer);
+      result = find_directory(B_USER_NONPACKAGED_FONTS_DIRECTORY, volume, false, buffer, sizeof(buffer));
+      loadfonts(screen, buffer);
 #elif defined(__APPLE__)
       loadfonts(screen, "/System/Library/Fonts");
       loadfonts(screen, "/Library/Fonts");
-      loadfonts(screen, macos_fontsPath());
+      loadfonts(screen, apple_fontsPath());
       loadfonts(screen, "/usr/share/fonts");
       loadfonts(screen, "/usr/X11R6/lib/X11/fonts");
 #elif defined(__sun__)
@@ -1217,7 +1222,7 @@ void receive_some_font_info(SDL_Surface * screen)
   waitpid(font_scanner_pid, &status, 0);
   if (WIFSIGNALED(status) || font_thread_aborted)
     {
-      printf("child killed by signal %u\n", WTERMSIG(status));
+      fprintf(stderr, "child killed by signal %u\n", WTERMSIG(status));
       user_font_families = NULL;
       num_font_families = 0;
       font_thread_done = 1;
@@ -1449,7 +1454,7 @@ static int do_surfcmp(const SDL_Surface * const *const v1, const SDL_Surface * c
 
   if (s1 == s2)
     {
-      printf("s1==s2?\n");
+      fprintf(stderr, "s1==s2?\n");
       return 0;
     }
   if (!s1 || !s2 || !s1->w || !s2->w || !s1->h || !s2->h || !s1->format || !s2->format)
@@ -1555,7 +1560,7 @@ out:
   while (count--)
     {
       if (surfs[count] == NULL)
-        printf("TRYING TO RE-FREE!");
+        fprintf(stderr, "TRYING TO RE-FREE!");
       else
         {
           SDL_FreeSurface(surfs[count]);
