@@ -4,7 +4,7 @@
   For Tux Paint
   Language-related functions
 
-  Copyright (c) 2002-2014 by Bill Kendrick and others
+  Copyright (c) 2002-2020 by Bill Kendrick and others
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -25,7 +25,7 @@
 
   $Id$
 
-  June 14, 2002 - December 11, 2016
+  June 14, 2002 - July 26, 2020
 */
 
 #include <stdio.h>
@@ -155,6 +155,7 @@ const char *lang_prefixes[NUM_LANGS] = {
   "sat@olchiki",
   "sat",
   "sa",
+  "sc",
   "sd",
   "sd@devanagari",
   "shs",
@@ -239,7 +240,6 @@ int need_right_to_left;
 int need_right_to_left_word;
 const char *lang_prefix, *short_lang_prefix;
 
-int num_wished_langs = 0;
 w_langs wished_langs[255];
 
 /* Mappings from human-readable language names (found in
@@ -363,7 +363,7 @@ static const language_to_locale_struct language_to_locale_array[] = {
   {"luganda", "lg_UG.UTF-8"},
   {"luxembourgish", "lb_LU.UTF-8"},
   {"letzebuergesch", "lb_LU.UTF-8"},
-  {"konkani-devaganari", "kok_IN.UTF-8"},
+  {"konkani-devanagari", "kok_IN.UTF-8"},
   {"konkani-roman", "kok@roman"},
   {"maithili", "mai_IN.UTF-8"},
   {"macedonian", "mk_MK.UTF-8"},
@@ -399,8 +399,10 @@ static const language_to_locale_struct language_to_locale_array[] = {
   {"russian", "ru_RU.UTF-8"},
   {"russkiy", "ru_RU.UTF-8"},
   {"sanskrit", "sa_IN.UTF-8"},
-  {"santali-devaganari", "sat_IN.UTF-8"},
+  {"santali-devanagari", "sat_IN.UTF-8"},
   {"santali-ol-chiki", "sat@olchiki"},
+  {"sardinian", "sc_IT"},
+  {"sardu", "sc_IT"},
   {"serbian", "sr_RS.UTF-8"},   /* Was sr_YU, but that's not in /usr/share/i18n/SUPPORTED, and sr_RS is -bjk 2014.08.04 */
   {"serbian-latin", "sr_RS@latin"},
   {"shuswap", "shs_CA.UTF-8"},
@@ -514,7 +516,7 @@ static void show_lang_usage(int exitcode)
 /* cgg */ "  kiga         chiga\n"
 /* rw */ "  kinyarwanda\n"
 /* tlh */ "  klingon      tlhIngan\n"
-/* kok */ "  konkani-devaganari\n"
+/* kok */ "  konkani-devanagari\n"
 /* kok@roman */ "  konkani-roman\n"
 /* ko */ "  korean\n"
 /* ku */ "  kurdish\n"
@@ -545,8 +547,9 @@ static void show_lang_usage(int exitcode)
 /* ro */ "  romanian\n"
 /* ru */ "  russian      russkiy\n"
 /* sa */ "  sanskrit\n"
-/* sat */ "  santali-devaganari\n"
+/* sat */ "  santali-devanagari\n"
 /* sat@olchiki */ "  santali-ol-chiki\n"
+/* sc */ "  sardinian    sardu\n"
 /* gd */ "  scottish     scottish-gaelic        ghaidhlig\n"
 /* sr */ "  serbian\n"
 /* sr@latin */ "  serbian-latin\n"
@@ -671,7 +674,7 @@ static void show_locale_usage(FILE * f, const char *const prg)
           "  lb_LU   (Luxembourgish Letzebuergesch)\n"
           "  lv_LV   (Latvian)\n"
           "  lt_LT   (Lithuanian   Lietuviu)\n"
-          "  kok_IN  (Konkani (Devaganari))\n"
+          "  kok_IN  (Konkani (Devanagari))\n"
           "  kok@roman  (Konkani (Roman))\n"
           "  mai_IN  (Maithili)\n"
           "  mk_MK   (Macedonian)\n"
@@ -695,6 +698,7 @@ static void show_locale_usage(FILE * f, const char *const prg)
           "  sa_IN   (Sanskrit)\n"
           "  sat_IN  (Santali)\n"
           "  sat@olchiki  (Santali (Ol-Chiki))\n"
+          "  sc_IT   (Sardinian)\n"
           "  sd_IN@devanagari  (Sindhi (Devanagari))\n"
           "  sd_IN  (Sindhii (Perso-Arabic))\n"
           "  shs_CA  (Shuswap      Secwepemctin)\n"
@@ -979,33 +983,66 @@ static void mysetenv(const char *name, const char *value)
  * @param loc Locale
  * @return The Y-nudge value for font rendering in the language.
  */
-static int set_current_language(const char *restrict locale_choice) MUST_CHECK;
 
-static int set_current_language(const char *restrict loc)
+static int set_current_language(const char *restrict loc, int * ptr_num_wished_langs)
 {
   int i;
-  int y_nudge = 0;
+  int j = 0;
   char *oldloc;
   char *env_language;
+  char *env_language_lang;
+  char *env;
+  int num_wished_langs = 0;
 
+  *ptr_num_wished_langs = 0;
 
   if (strlen(loc) > 0)
     {
       /* Got command line or config file language */
+      DEBUG_PRINTF("Language via config: %s\n", loc);
       mysetenv("LANGUAGE", loc);
     }
   else
     {
+      DEBUG_PRINTF("Language NOT set via config\n");
+
       /* Find what language to use from env vars */
-      if (getenv("LANGUAGE") == NULL)
+      env = getenv("LANGUAGE");
+      if (env == NULL || env[0] == '\0')
         {
-          if (getenv("LC_ALL"))
-            mysetenv("LANGUAGE", getenv("LC_ALL"));
-          else if (getenv("LC_MESSAGES"))
-            mysetenv("LANGUAGE", getenv("LC_MESSAGES"));
-          else if (getenv("LANG"))
-            mysetenv("LANGUAGE", getenv("LANG"));
+	  env = getenv("LC_ALL");
+          if (env != NULL && env[0] != '\0')
+	    {
+              DEBUG_PRINTF("Language via LC_ALL: %s\n", getenv("LC_ALL"));
+              mysetenv("LANGUAGE", getenv("LC_ALL"));
+	    }
+          else
+            {
+	      env = getenv("LC_MESSAGES");
+              if (env != NULL && env[0] != '\0')
+	        {
+                  DEBUG_PRINTF("Language via LC_MESSAGES: %s\n", getenv("LC_MESSAGES"));
+                  mysetenv("LANGUAGE", getenv("LC_MESSAGES"));
+	        }
+	      else
+	        {
+	          env = getenv("LANG");
+                  if (env != NULL && env[0] != '\0')
+        	    {
+                      DEBUG_PRINTF("Language via LANG: %s\n", getenv("LANG"));
+                      mysetenv("LANGUAGE", getenv("LANG"));
+        	    }
+		  else
+	            {
+                      DEBUG_PRINTF("No language set!\n");
+	            }
+		}
+	    }
         }
+      else
+        {
+          DEBUG_PRINTF("Language was set to '%s'\n", getenv("LANGUAGE"));
+	}
     }
 
   oldloc = strdup(loc);
@@ -1013,15 +1050,13 @@ static int set_current_language(const char *restrict loc)
   /* First set the locale according to the environment, then try to overwrite with loc,
      after that, ctype_utf8() call will test the compatibility with utf8 and try to load
      a different locale if the resulting one is not compatible. */
-#ifdef DEBUG
-  printf("Locale BEFORE is: %s\n", setlocale(LC_ALL, NULL));    //EP
-#endif
+  DEBUG_PRINTF("Locale BEFORE is: %s\n", setlocale(LC_ALL, NULL));    //EP
+
   setlocale(LC_ALL, "");
   setlocale(LC_ALL, loc);
   ctype_utf8();
-#ifdef DEBUG
-  printf("Locale AFTER is: %s\n", setlocale(LC_ALL, NULL));     //EP
-#endif
+
+  DEBUG_PRINTF("Locale AFTER is: %s\n", setlocale(LC_ALL, NULL));     //EP
 
   bindtextdomain("tuxpaint", LOCALEDIR);
   /* Old version of glibc does not have bind_textdomain_codeset() */
@@ -1081,8 +1116,6 @@ static int set_current_language(const char *restrict loc)
         mysetenv("LANGUAGE", "C");
     }
   env_language = strdup(getenv("LANGUAGE"));
-  int j = 0;
-  char *env_language_lang;
 
   if (*env_language)
     {
@@ -1102,7 +1135,6 @@ static int set_current_language(const char *restrict loc)
               if (lang_y_nudge[i][0] == langint)
                 {
                   wished_langs[j].lang_y_nudge = lang_y_nudge[i][1];
-                  //printf("y_nudge = %d\n", y_nudge);
                   break;
                 }
             }
@@ -1128,18 +1160,6 @@ static int set_current_language(const char *restrict loc)
   need_right_to_left = wished_langs[0].need_right_to_left;
   need_right_to_left_word = wished_langs[0].need_right_to_left_word;
 
-#if 0
-  for (i = 0; lang_y_nudge[i][0] != -1; i++)
-    {
-      // printf("lang_y_nudge[%d][0] = %d\n", i, lang_y_nudge[i][0]);
-      if (lang_y_nudge[i][0] == langint)
-        {
-          y_nudge = lang_y_nudge[i][1];
-          //printf("y_nudge = %d\n", y_nudge);
-          break;
-        }
-    }
-#endif
 #ifdef DEBUG
   fprintf(stderr, "DEBUG: Language is %s (%d) %s/%s\n",
           lang_prefix, langint, need_right_to_left ? "(RTL)" : "", need_right_to_left_word ? "(RTL words)" : "");
@@ -1148,9 +1168,9 @@ static int set_current_language(const char *restrict loc)
 
   free(oldloc);
 
-#ifdef DEBUG
-  printf("lang_prefixes[%d] is \"%s\"\n", get_current_language(), lang_prefixes[get_current_language()]);
-#endif
+  DEBUG_PRINTF("lang_prefixes[%d] is \"%s\"\n", get_current_language(), lang_prefixes[get_current_language()]);
+
+  *ptr_num_wished_langs = num_wished_langs;
 
   return wished_langs[0].lang_y_nudge;
 }
@@ -1162,16 +1182,15 @@ static int set_current_language(const char *restrict loc)
  * if asked (either 'locale' or 'lang' are "help"), or if the
  * given input is not recognized.
  *
- * @param lang Language name (or NULL)
- * @param locale Locale (or NULL)
+ * @param char * lang Language name (or NULL)
+ * @param char * locale Locale (or NULL)
+ * @param int * a place to return the number of languages we want to use, when scanning stamp descriptions 
  * @return Y-nudge
  */
-int setup_i18n(const char *restrict lang, const char *restrict locale)
+int setup_i18n(const char *restrict lang, const char *restrict locale, int * num_wished_langs)
 {
-#ifdef DEBUG
-  printf("lang %p, locale %p\n", lang, locale);
-  printf("lang \"%s\", locale \"%s\"\n", lang, locale);
-#endif
+  DEBUG_PRINTF("lang %p, locale %p\n", lang, locale);
+  DEBUG_PRINTF("lang \"%s\", locale \"%s\"\n", lang, locale);
 
   if (locale)
     {
@@ -1186,7 +1205,7 @@ int setup_i18n(const char *restrict lang, const char *restrict locale)
 
   if (lang)
     locale = language_to_locale(lang);
-  return set_current_language(locale);
+  return set_current_language(locale, num_wished_langs);
 }
 
 #ifdef NO_SDLPANGO
@@ -1195,6 +1214,7 @@ int setup_i18n(const char *restrict lang, const char *restrict locale)
  */
 int smash_i18n(void)
 {
-  return set_current_language("C");
+  int tmp;
+  return set_current_language("C", &tmp);
 }
 #endif
