@@ -2,7 +2,7 @@
   im.c
 
   Input method handling
-  Copyright (c)2007 by Mark K. Kim and others
+  Copyright (c) 2007-2019 by Mark K. Kim and others
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -45,7 +45,6 @@
 #include "im.h"
 
 
-
 /* ***************************************************************************
 * I18N GETTEXT
 */
@@ -905,12 +904,12 @@ static int im_event_zh_tw(IM_DATA * im, SDL_keysym ks)
 
     case IM_REQ_FREE:          /* Free allocated resources */
       charmap_free(&cm);
-      /* go onto full reset */
+      FALL_THROUGH; /* go onto full reset */
 
     case IM_REQ_RESET_FULL:    /* Full reset */
       cm.section = SEC_ENGLISH;
       im->tip_text = im_tip_text[IM_TIP_ENGLISH];
-      /* go onto soft reset */
+      FALL_THROUGH; /* go onto soft reset */
 
     case IM_REQ_RESET_SOFT:    /* Soft reset */
       im->s[0] = L'\0';
@@ -971,7 +970,7 @@ static int im_event_zh_tw(IM_DATA * im, SDL_keysym ks)
       /* Left-Alt & Right-Alt mapped to mode-switch */
     case SDLK_RALT:
     case SDLK_LALT:
-      cm.section = ((cm.section + 1) % SEC_TOTAL);  /* Change section */
+      cm.section = ((cm.section + 1) % SEC_TOTAL);      /* Change section */
       im_softreset(im);         /* Soft reset */
 
       /* Set tip text */
@@ -1124,12 +1123,12 @@ static int im_event_th(IM_DATA * im, SDL_keysym ks)
 
     case IM_REQ_FREE:          /* Free allocated resources */
       charmap_free(&cm);
-      /* go onto full reset */
+      FALL_THROUGH; /* go onto full reset */
 
     case IM_REQ_RESET_FULL:    /* Full reset */
       cm.section = SEC_ENGLISH;
       im->tip_text = im_tip_text[IM_TIP_ENGLISH];
-      /* go onto soft reset */
+      FALL_THROUGH; /* go onto soft reset */
 
     case IM_REQ_RESET_SOFT:    /* Soft reset */
       im->s[0] = L'\0';
@@ -1190,7 +1189,7 @@ static int im_event_th(IM_DATA * im, SDL_keysym ks)
 
       /* Right-Alt mapped to mode-switch */
     case SDLK_RALT:
-      cm.section = ((cm.section + 1) % SEC_TOTAL);  /* Change section */
+      cm.section = ((cm.section + 1) % SEC_TOTAL);      /* Change section */
       im_softreset(im);         /* Soft reset */
 
       /* Set tip text */
@@ -1343,12 +1342,12 @@ static int im_event_ja(IM_DATA * im, SDL_keysym ks)
 
     case IM_REQ_FREE:          /* Free allocated resources */
       charmap_free(&cm);
-      /* go onto full reset */
+      FALL_THROUGH; /* go onto full reset */
 
     case IM_REQ_RESET_FULL:    /* Full reset */
       cm.section = SEC_ENGLISH;
       im->tip_text = im_tip_text[IM_TIP_ENGLISH];
-      /* go onto soft reset */
+      FALL_THROUGH; /* go onto soft reset */
 
     case IM_REQ_RESET_SOFT:    /* Soft reset */
       im->s[0] = L'\0';
@@ -1409,7 +1408,7 @@ static int im_event_ja(IM_DATA * im, SDL_keysym ks)
 
       /* Right-Alt mapped to mode-switch */
     case SDLK_RALT:
-      cm.section = ((cm.section + 1) % SEC_TOTAL);  /* Change section */
+      cm.section = ((cm.section + 1) % SEC_TOTAL);      /* Change section */
       im_softreset(im);         /* Soft reset */
 
       /* Set tip text */
@@ -1590,12 +1589,12 @@ static int im_event_ko(IM_DATA * im, SDL_keysym ks)
 
     case IM_REQ_FREE:          /* Free allocated resources */
       charmap_free(&cm);
-      /* go onto full reset */
+      FALL_THROUGH; /* go onto full reset */
 
     case IM_REQ_RESET_FULL:    /* Full reset */
       cm.section = SEC_ENGLISH;
       im->tip_text = im_tip_text[IM_TIP_ENGLISH];
-      /* go onto soft reset */
+      FALL_THROUGH; /* go onto soft reset */
 
     case IM_REQ_RESET_SOFT:    /* Soft reset */
       im->s[0] = L'\0';
@@ -1656,7 +1655,7 @@ static int im_event_ko(IM_DATA * im, SDL_keysym ks)
       /* Right-Alt mapped to mode-switch */
     case SDLK_LALT:
     case SDLK_RALT:
-      cm.section = ((cm.section + 1) % SEC_TOTAL);  /* Change section */
+      cm.section = ((cm.section + 1) % SEC_TOTAL);      /* Change section */
       im_softreset(im);         /* Soft reset */
 
       /* Set tip text */
@@ -1681,7 +1680,7 @@ static int im_event_ko(IM_DATA * im, SDL_keysym ks)
             im->redraw--;
           ks.unicode = L'\0';
         }
-      /* continue processing: */
+      FALL_THROUGH; /* continue processing: */
 
       /* Actual character processing */
     default:
