@@ -1,3 +1,25 @@
+/*
+  onscreen_keyboard.c
+
+  Copyright (c) 2020
+  http://www.tuxpaint.org/
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  (See COPYING.txt)
+*/
+
 #include "onscreen_keyboard.h"
 
 //#define DEBUG_OSK_COMPOSEMAP
@@ -61,15 +83,27 @@ static void mtw(wchar_t * wtok, char *tok)
 #define mbstowcs(wtok, tok, size) mtw(wtok, tok)
 #endif
 
-struct osk_keyboard *osk_create(char *layout_name, SDL_Surface * canvas, SDL_Surface * button_up,
-                                SDL_Surface * button_down, SDL_Surface * button_off, SDL_Surface * button_nav,
-                                SDL_Surface * button_hold, SDL_Surface * oskdel, SDL_Surface * osktab,
-                                SDL_Surface * oskenter, SDL_Surface * oskcapslock, SDL_Surface * oskshift,
+struct osk_keyboard *osk_create(char * layout_name, SDL_Surface * canvas,
+                                SDL_Surface * LG_button_up, SDL_Surface * LG_button_down,
+                                SDL_Surface * LG_button_off, SDL_Surface * LG_button_nav,
+                                SDL_Surface * LG_button_hold,
+                                SDL_Surface * LG_oskdel, SDL_Surface * LG_osktab, SDL_Surface * LG_oskenter,
+                                SDL_Surface * LG_oskcapslock, SDL_Surface * LG_oskshift,
+                                SDL_Surface * SM_button_up, SDL_Surface * SM_button_down,
+                                SDL_Surface * SM_button_off, SDL_Surface * SM_button_nav,
+                                SDL_Surface * SM_button_hold,
+                                SDL_Surface * SM_oskdel, SDL_Surface * SM_osktab, SDL_Surface * SM_oskenter,
+                                SDL_Surface * SM_oskcapslock, SDL_Surface * SM_oskshift,
                                 int disable_change)
 {
-  SDL_Surface *surface;
-  osk_layout *layout;
-  on_screen_keyboard *keyboard;
+  SDL_Surface * surface;
+  SDL_Surface * button_up, * button_down;
+  SDL_Surface * button_off, * button_nav;
+  SDL_Surface * button_hold;
+  SDL_Surface * oskdel, * osktab, * oskenter;
+  SDL_Surface * oskcapslock, * oskshift;
+  osk_layout * layout;
+  on_screen_keyboard * keyboard;
 
   keyboard = malloc(sizeof(on_screen_keyboard));
 
@@ -79,20 +113,46 @@ struct osk_keyboard *osk_create(char *layout_name, SDL_Surface * canvas, SDL_Sur
   layout = load_layout(keyboard, layout_name);
   if (!layout)
     {
-      printf("Error trying to load the required layout %s\n", layout_name);
+      fprintf(stderr, "Error trying to load the required layout %s\n", layout_name);
       layout = load_layout(keyboard, strdup("default.layout"));
       if (!layout)
         {
-          printf("Error trying to load the default layout\n");
+          fprintf(stderr, "Error trying to load the default layout\n");
           return NULL;
         }
-      printf("Loaded the default layout instead.\n");
+      fprintf(stderr, "Loaded the default layout instead.\n");
     }
 
 #ifdef DEBUG
   printf("w %i, h %i\n", layout->width, layout->height);
 #endif
 
+  if (layout->width * LG_button_up->w >= (canvas->w - 48 * 4) * 0.9 ||
+      layout->height * LG_button_up->h >= canvas->h * 0.5) {
+      /* Full-size buttons too large, use small buttons */
+      button_up = SM_button_up;
+      button_down = SM_button_down;
+      button_off = SM_button_off;
+      button_nav = SM_button_nav;
+      button_hold = SM_button_hold;
+      oskdel = SM_oskdel;
+      osktab = SM_osktab;
+      oskenter = SM_oskenter;
+      oskcapslock = SM_oskcapslock;
+      oskshift = SM_oskshift;
+  } else {
+      button_up = LG_button_up;
+      button_down = LG_button_down;
+      button_off = LG_button_off;
+      button_nav = LG_button_nav;
+      button_hold = LG_button_hold;
+      oskdel = LG_oskdel;
+      osktab = LG_osktab;
+      oskenter = LG_oskenter;
+      oskcapslock = LG_oskcapslock;
+      oskshift = LG_oskshift;
+  }
+
   surface = SDL_CreateRGBSurface(canvas->flags,
                                  layout->width * button_up->w,
                                  layout->height * button_up->h,
@@ -100,10 +160,11 @@ struct osk_keyboard *osk_create(char *layout_name, SDL_Surface * canvas, SDL_Sur
                                  canvas->format->Rmask, canvas->format->Gmask, canvas->format->Bmask, 0);
   if (!surface)
     {
-      printf("Error creating the onscreen keyboard surface\n");
+      fprintf(stderr, "Error creating the onscreen keyboard surface\n");
       return NULL;
     }
   //  keyboard->name = layout_name;
+  keyboard->canvas_ptr = canvas;
   keyboard->layout = layout;
   keyboard->surface = surface;
   keyboard->rect.x = 0;
@@ -137,6 +198,27 @@ struct osk_keyboard *osk_create(char *layout_name, SDL_Surface * canvas, SDL_Sur
   keyboard->kmdf.dead3 = NULL;
   keyboard->kmdf.dead4 = NULL;
 
+  keyboard->LG_button_up = LG_button_up;
+  keyboard->LG_button_down = LG_button_down;
+  keyboard->LG_button_off = LG_button_off;
+  keyboard->LG_button_nav = LG_button_nav;
+  keyboard->LG_button_hold = LG_button_hold;
+  keyboard->LG_oskdel = LG_oskdel;
+  keyboard->LG_osktab = LG_osktab;
+  keyboard->LG_oskenter = LG_oskenter;
+  keyboard->LG_oskcapslock = LG_oskcapslock;
+  keyboard->LG_oskshift = LG_oskshift;
+  keyboard->SM_button_up = SM_button_up;
+  keyboard->SM_button_down = SM_button_down;
+  keyboard->SM_button_off = SM_button_off;
+  keyboard->SM_button_nav = SM_button_nav;
+  keyboard->SM_button_hold = SM_button_hold;
+  keyboard->SM_oskdel = SM_oskdel;
+  keyboard->SM_osktab = SM_osktab;
+  keyboard->SM_oskenter = SM_oskenter;
+  keyboard->SM_oskcapslock = SM_oskcapslock;
+  keyboard->SM_oskshift = SM_oskshift;
+
   SDL_FillRect(surface, NULL,
                SDL_MapRGB(surface->format, keyboard->layout->bgcolor.r, keyboard->layout->bgcolor.g,
                           keyboard->layout->bgcolor.b));
@@ -155,6 +237,7 @@ static struct osk_layout *load_layout(on_screen_keyboard * keyboard, char *layou
   char *filename;
   char *key, *value;
   osk_layout *layout;
+  char * __attribute__((unused)) tmp_ptr;
 
   layout = malloc(sizeof(osk_layout));
   layout->name = NULL;
@@ -176,7 +259,7 @@ static struct osk_layout *load_layout(on_screen_keyboard * keyboard, char *layou
           fi = fopen(filename, "r");
           if (fi == NULL)
             {
-              printf("Can't open either %s nor %s\n", layout_name, filename);
+              fprintf(stderr, "Can't open either %s nor %s\n", layout_name, filename);
               /* Fallback to default */
               snprintf(filename, 255, "%sosk/default.layout", DATA_PREFIX);
               fi = fopen(filename, "r");
@@ -194,7 +277,7 @@ static struct osk_layout *load_layout(on_screen_keyboard * keyboard, char *layou
   free(filename);
   if (fi == NULL)
     {
-      printf("Can't load the on screen keyboard layout\n");
+      fprintf(stderr, "Can't load the on screen keyboard layout\n");
       return NULL;
     }
 
@@ -205,7 +288,7 @@ static struct osk_layout *load_layout(on_screen_keyboard * keyboard, char *layou
 
   while (!feof(fi))
     {
-      fgets(line, 1023, fi);
+      tmp_ptr = fgets(line, 1023, fi);
 
       if (is_blank_or_comment(line))
         continue;
@@ -277,6 +360,7 @@ void load_hlayout(osk_layout * layout, char *hlayout_name)
   char *key, *fontpath;
   char *plain_label, *top_label, *altgr_label, *shift_altgr_label;
   FILE *fi;
+  char * __attribute__((unused)) tmp_ptr;
 
   key_number = line_number = 0;
   width = height = 0;
@@ -295,7 +379,7 @@ void load_hlayout(osk_layout * layout, char *hlayout_name)
       fi = fopen(filename, "r");
       if (fi == NULL)
         {
-          printf("Can't open either %s nor %s\n", hlayout_name, filename);
+          fprintf(stderr, "Can't open either %s nor %s\n", hlayout_name, filename);
           layout->keys = NULL;
           free(filename);
           return;
@@ -342,7 +426,7 @@ void load_hlayout(osk_layout * layout, char *hlayout_name)
           allocated = 1;
         }
 
-      fgets(line, 1023, fi);
+      tmp_ptr = fgets(line, 1023, fi);
 
       if (is_blank_or_comment(line))
         continue;
@@ -466,6 +550,7 @@ void load_keymap(osk_layout * layout, char *keymap_name)
   char *ksname1, *ksname2, *ksname3, *ksname4;
   char *line;
   FILE *fi;
+  char * __attribute__((unused)) tmp_ptr;
 
   filename = malloc(sizeof(char) * 255);
 
@@ -479,7 +564,7 @@ void load_keymap(osk_layout * layout, char *keymap_name)
       fi = fopen(filename, "r");
       if (fi == NULL)
         {
-          printf("Can't open either %s nor %s\n", keymap_name, filename);
+          fprintf(stderr, "Can't open either %s nor %s\n", keymap_name, filename);
           layout->keys = NULL;
           free(filename);
           return;
@@ -502,7 +587,7 @@ void load_keymap(osk_layout * layout, char *keymap_name)
 
   while (!feof(fi))
     {
-      fgets(line, 1023, fi);
+      tmp_ptr = fgets(line, 1023, fi);
 
       if (is_blank_or_comment(line))
         continue;
@@ -652,6 +737,7 @@ static void load_composemap(osk_layout * layout, char *composemap_name)
   char **pointer;
   char *line;
   FILE *fi;
+  char * __attribute__((unused)) tmp_ptr;
 
   pointer = malloc(sizeof(wchar_t *));
   filename = malloc(sizeof(char) * 255);
@@ -666,7 +752,7 @@ static void load_composemap(osk_layout * layout, char *composemap_name)
       fi = fopen(filename, "r");
       if (fi == NULL)
         {
-          printf("Can't open either %s nor %s\n", composemap_name, filename);
+          fprintf(stderr, "Can't open either %s nor %s\n", composemap_name, filename);
           layout->keys = NULL;
           free(filename);
           return;
@@ -684,7 +770,7 @@ static void load_composemap(osk_layout * layout, char *composemap_name)
 
   while (!feof(fi))
     {
-      fgets(line, 1023, fi);
+      tmp_ptr = fgets(line, 1023, fi);
 
       if (is_blank_or_comment(line))
         continue;
@@ -760,6 +846,7 @@ static void load_keysymdefs(osk_layout * layout, char *keysymdefs_name)
   char *filename;
   char *line;
   FILE *fi;
+  char * __attribute__((unused)) tmp_ptr;
 
   filename = malloc(sizeof(char) * 255);
 
@@ -773,7 +860,7 @@ static void load_keysymdefs(osk_layout * layout, char *keysymdefs_name)
       fi = fopen(filename, "r");
       if (fi == NULL)
         {
-          printf("Can't open either %s nor %s\n", keysymdefs_name, filename);
+          fprintf(stderr, "Can't open either %s nor %s\n", keysymdefs_name, filename);
           layout->keysymdefs = NULL;
           free(filename);
           return;
@@ -789,7 +876,7 @@ static void load_keysymdefs(osk_layout * layout, char *keysymdefs_name)
 
   while (!feof(fi))
     {
-      fgets(line, 1023, fi);
+      tmp_ptr = fgets(line, 1023, fi);
       if (strncmp("#define XK_", line, 11) != 0)
         continue;
 
@@ -978,36 +1065,40 @@ static int is_blank_or_comment(char *line)
 /* } */
 
 
-/* Fixme: Is it safe to supose that if a font is loaded at one size, it will be loaded at any size? */
-/* Fixme: sizes should be dynamically adapted to the button size */
-/* Fixme: starting a layout with one font causes all other layouts be in that font */
+/* FIXME: Is it safe to supose that if a font is loaded at one size, it will be loaded at any size? */
+/* FIXME: starting a layout with one font causes all other layouts be in that font */
 static void keybd_prepare(on_screen_keyboard * keyboard)
 {
   char *fontname;
-
+  int font_height;
+  
+  /* Pick a height (e.g., 16pt for small (24x24), 32pt for large (48x48) buttons) */
+  font_height = ((keyboard->button_up->h * 2) / 3);
+  
   fontname = malloc(sizeof(char) * 255);
   if (keyboard->osk_fonty == NULL)
     {
+      
       if (keyboard->layout->fontpath)
         {
           /* First try if it is an absolute path */
-          keyboard->osk_fonty = TTF_OpenFont(keyboard->layout->fontpath, 12);
+          keyboard->osk_fonty = TTF_OpenFont(keyboard->layout->fontpath, font_height);
           if (keyboard->osk_fonty == NULL)
             {
               /* Now trying if it is relative to DATA_PREFIX/fonts/ */
               snprintf(fontname, 255, "%s/fonts/%s", DATA_PREFIX, keyboard->layout->fontpath);
 
-              keyboard->osk_fonty = TTF_OpenFont(fontname, 12);
+              keyboard->osk_fonty = TTF_OpenFont(fontname, font_height);
               if (keyboard->osk_fonty == NULL)
                 {
                   /* Perhaps it is relative to DATA_PREFIX only? */
                   snprintf(fontname, 255, "%s/%s", DATA_PREFIX, keyboard->layout->fontpath);
-                  keyboard->osk_fonty = TTF_OpenFont(fontname, 12);
+                  keyboard->osk_fonty = TTF_OpenFont(fontname, font_height);
                   if (keyboard->osk_fonty == NULL)
                     {
                       /* Or to DATA_PREFIX/fonts/locale/ ? */
                       snprintf(fontname, 255, "%s/fonts/locale/%s", DATA_PREFIX, keyboard->layout->fontpath);
-                      keyboard->osk_fonty = TTF_OpenFont(fontname, 12);
+                      keyboard->osk_fonty = TTF_OpenFont(fontname, font_height);
                     }
                 }
             }
@@ -1017,7 +1108,7 @@ static void keybd_prepare(on_screen_keyboard * keyboard)
         {
           /* Going with the default */
           sprintf(fontname, "%s/fonts/FreeSansBold.ttf", DATA_PREFIX);
-          keyboard->osk_fonty = TTF_OpenFont(fontname, 12);
+          keyboard->osk_fonty = TTF_OpenFont(fontname, font_height);
         }
 
       if (keyboard->osk_fonty == NULL)
@@ -1660,9 +1751,20 @@ struct osk_keyboard *osk_clicked(on_screen_keyboard * keyboard, int x, int y)
 
 
           new_keyboard =
-            osk_create(name, keyboard->surface, keyboard->button_up, keyboard->button_down, keyboard->button_off,
-                       keyboard->button_nav, keyboard->button_hold, keyboard->oskdel, keyboard->osktab,
-                       keyboard->oskenter, keyboard->oskcapslock, keyboard->oskshift, keyboard->disable_change);
+            osk_create(name, keyboard->canvas_ptr,
+                       keyboard->LG_button_up, keyboard->LG_button_down,
+                       keyboard->LG_button_off, keyboard->LG_button_nav,
+                       keyboard->LG_button_hold,
+                       keyboard->LG_oskdel, keyboard->LG_osktab,
+                       keyboard->LG_oskenter, keyboard->LG_oskcapslock,
+                       keyboard->LG_oskshift,
+                       keyboard->SM_button_up, keyboard->SM_button_down,
+                       keyboard->SM_button_off, keyboard->SM_button_nav,
+                       keyboard->SM_button_hold,
+                       keyboard->SM_oskdel, keyboard->SM_osktab,
+                       keyboard->SM_oskenter, keyboard->SM_oskcapslock,
+                       keyboard->SM_oskshift,
+                       keyboard->disable_change);
 
           free(aux_list_ptr);
 
